R

Struct R 

pub struct R(/* private fields */);
Register UNDERSIZE_FRAMES reader

Implementations

Source

impl R

pub fn count_undersize(&self) -> FieldReaderRaw<u16, u16>

Bits 0:9 - Undersize frames received - a 10 bit register counting the number of frames received less than 64 bytes in length (10/100 mode or gigabit mode, full duplex) that do not have either a CRC error or an alignment error. In gigabit mode, half duplex, this register counts either frames not conforming to the minimum slot time of 512 bytes or frames not conforming to the minimum frame size once bursting is active.

Methods from Deref<Target = R<UNDERSIZE_FRAMES_SPEC>>

pub fn bits(&self) -> <REG as RegisterSpec>::Ux

Reads raw bits from register.